<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Acknowledgements</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1238"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1242"/>
        <source>%1 is released under %2</source>
        <translation>%1 is released under %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="900"/>
        <source>Black</source>
        <translation>Black</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="903"/>
        <source>White</source>
        <translation>White</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="906"/>
        <source>Dark Gray</source>
        <translation>Dark Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="909"/>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="912"/>
        <source>Light Gray</source>
        <translation>Light Gray</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="915"/>
        <source>Red</source>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="918"/>
        <source>Green</source>
        <translation>Green</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="921"/>
        <source>Blue</source>
        <translation>Blue</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="924"/>
        <source>Cyan</source>
        <translation>Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="927"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="930"/>
        <source>Yellow</source>
        <translation>Yellow</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="933"/>
        <source>Dark Red</source>
        <translation>Dark Red</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="936"/>
        <source>Dark Green</source>
        <translation>Dark Green</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="939"/>
        <source>Dark Blue</source>
        <translation>Dark Blue</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="942"/>
        <source>Dark Cyan</source>
        <translation>Dark Cyan</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="945"/>
        <source>Dark Magenta</source>
        <translation>Dark Magenta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="948"/>
        <source>Dark Yellow</source>
        <translation>Dark Yellow</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="85"/>
        <source>Enter a new shortcut</source>
        <translation>Enter a new shortcut</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="471"/>
        <source>Stop reading</source>
        <translation>Stop reading</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="473"/>
        <source>Text to Speech</source>
        <translation>Text to Speech</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="496"/>
        <source>Translate</source>
        <translation>Translate</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="518"/>
        <source>Speech To Text</source>
        <translation>Speech To Text</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="232"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1175"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="255"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished">Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="256"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1596"/>
        <source>Print</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="272"/>
        <source>Basic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="287"/>
        <source>Printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Copies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="321"/>
        <source>Page range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="323"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Current page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="325"/>
        <source>Select pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="340"/>
        <source>Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="364"/>
        <source>Portrait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="374"/>
        <source>Landscape</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="402"/>
        <source>Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="412"/>
        <source>Color mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1553"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="414"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1605"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1620"/>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="425"/>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Narrow (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Normal (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Moderate (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="427"/>
        <source>Customize (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="433"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="501"/>
        <source>Actual size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="510"/>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="541"/>
        <source>Paper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="551"/>
        <source>Paper size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="564"/>
        <source>Print Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="575"/>
        <source>Duplex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="588"/>
        <source>N-up printing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>2 pages/sheet, 1×2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>4 pages/sheet, 2×2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>6 pages/sheet, 2×3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>9 pages/sheet, 3×3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="590"/>
        <source>16 pages/sheet, 4×4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="599"/>
        <source>Layout direction</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="644"/>
        <source>Page Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Collate pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="661"/>
        <source>Print pages in order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Front to back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="663"/>
        <source>Back to front</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="687"/>
        <source>Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="698"/>
        <source>Add watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Text watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Confidential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Draft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Sample</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="742"/>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Input your text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="773"/>
        <source>Picture watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="794"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Tile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="796"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="807"/>
        <source>Angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="823"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="844"/>
        <source>Transparency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="901"/>
        <source>Print to PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="902"/>
        <source>Save as Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1171"/>
        <source>Collapse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1294"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1301"/>
        <source>Flip on short edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1297"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <source>Flip on long edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1558"/>
        <source>Save</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>*.pdf</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1672"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2168"/>
        <source>Save as PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2207"/>
        <source>Save as image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2209"/>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="291"/>
        <source>Search</source>
        <translation>Search</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Replace</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Please input a new shortcut</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>None</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="171"/>
        <source>Stop reading</source>
        <translation>Stop reading</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="173"/>
        <source>Text to Speech</source>
        <translation>Text to Speech</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="196"/>
        <source>Translate</source>
        <translation>Translate</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="218"/>
        <source>Speech To Text</source>
        <translation>Speech To Text</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="109"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="454"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1334"/>
        <source>No search result</source>
        <translation>No search result</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="331"/>
        <source>Restore Defaults</source>
        <translation>Restore Defaults</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="163"/>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Please enter a new shortcut</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="527"/>
        <source>Theme</source>
        <translation>Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="529"/>
        <source>Light Theme</source>
        <translation>Light Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="530"/>
        <source>Dark Theme</source>
        <translation>Dark Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="531"/>
        <source>System Theme</source>
        <translation>System Theme</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="555"/>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="563"/>
        <source>About</source>
        <translation>About</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="570"/>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
</TS>
